==> apache-camel-3.18.7-src.zip: apache-camel-3.18.7/components/camel-netty-http/src/test/java/org/apache/camel/component/netty/http/NettyCamelWebsiteManualTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.netty.http;

import org.apache.camel.Exchange;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

@Disabled("For manual testing")
public class NettyCamelWebsiteManualTest extends CamelTestSupport {

    @Test
    public void testCamel() throws Exception {
        getMockEndpoint("mock:test").expectedMessageCount(1);

        template.sendBody("direct:in", null);

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:in")
                        .setHeader(Exchange.HTTP_METHOD, constant("GET"))
                        .to("netty-http:http://camel.apache.org/")
                        .to("log:test")
                        .to("mock:test");
            }
        };
    }
}

==> apache-camel-4.14.5-src.zip: apache-camel-4.14.5/components/camel-netty-http/src/test/java/org/apache/camel/component/netty/http/NettyCamelWebsiteManualTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.netty.http;

import org.apache.camel.Exchange;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

@Disabled("For manual testing")
public class NettyCamelWebsiteManualTest extends CamelTestSupport {

    @Test
    public void testCamel() throws Exception {
        getMockEndpoint("mock:test").expectedMessageCount(1);

        template.sendBody("direct:in", null);

        MockEndpoint.assertIsSatisfied(context);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:in")
                        .setHeader(Exchange.HTTP_METHOD, constant("GET"))
                        .to("netty-http:http://camel.apache.org/")
                        .to("log:test")
                        .to("mock:test");
            }
        };
    }
}
